@@ -10,18 +10,23 @@
 """Define exit state numbers for build harness CLI."""
 
 import dataclasses
+import enum
 import pathlib
 
+from ._logging import LoggingState
+
 
 @dataclasses.dataclass
 class CommandState:
     """Global click command state context."""
 
+    logging_state: LoggingState
     project_path: pathlib.Path
     venv_path: pathlib.Path
 
 
-class ExitState:
+@enum.unique
+class ExitState(enum.Enum):
     """Exit state enumeration."""
 
     UNKNOWN_ERROR = 100
@@ -52,3 +57,5 @@ class ExitState:
     BAD_REPO = 190
     BAD_GIT_EXE = 200
     BAD_PYPROJECTTOML = 210
+
+    BOOTSTRAP_FAILED = 220
