@@ -54,7 +54,9 @@ def validate_git(optional_git: typing.Optional[str]) -> None:
     if not system_git:
         raise GitNotFoundError("Git not available on users PATH")
     if not os.path.exists(system_git):
-        raise GitNotFoundError("User specified git invalid, {0}".format(system_git))
+        raise GitNotFoundError(
+            "User specified git invalid, {0}".format(system_git)
+        )
 
 
 @dataclasses.dataclass
@@ -86,12 +88,13 @@ def _parse_describe(describe_output: str) -> TagData:
 
 
 def get_tag_data(
-    repo_path: pathlib.Path, default_branch_name: str = DEFAULT_DEFAULT_BRANCH_NAME
+    repo_path: pathlib.Path,
+    default_branch_name: typing.Optional[str] = None,
 ) -> TagData:
     """
     Acquire tag, offset data for release id construction.
 
-    Assumes that the repo has already been set to the required HEAD state for the
+    Assumes that the repo has already been set to the required HEAD state.
 
     Args:
         repo_path: Path to git repository.
@@ -108,8 +111,8 @@ def get_tag_data(
             # Start with the nearest historical tag.
             result = this_repo.git.describe("--first-parent", "--tags")
 
-            # If HEAD is dryrun tagged then this is a dryrun so use that tag (ie.
-            # treat it as a release).
+            # If HEAD is dryrun tagged then this is a dryrun so use that tag
+            # (ie. treat it as a release).
             if (not _is_commit_tagged(this_repo.head.commit, this_repo)) and (
                 re.search(r"\+dryrun", result) is not None
             ):
@@ -123,17 +126,27 @@ def get_tag_data(
             tag_data = _parse_describe(result)
         except git.GitCommandError as e:
             log.debug("handling GitCommandError, {0}".format(str(e)))
-            number_commits = len(list(this_repo.iter_commits(default_branch_name)))
+            # NOTE: the fallback here is to assume the active branch is the
+            #       default branch. there might be unexpected side effects of
+            #       this choice.
+            this_branch = (
+                default_branch_name
+                if default_branch_name
+                else this_repo.active_branch.name
+            )
+            number_commits = len(list(this_repo.iter_commits(this_branch)))
             tag_data = TagData(tag="0.0.0", offset=str(number_commits))
 
     except TagDataError as e:
         log.debug("handling TagDataError, {0}".format(str(e)))
         # extreme fallback that is not expected to happen in practice
-        # use a PEP-440 local identifier to prevent publishing because at this point
-        # that is almost certainly not desirable
+        # use a PEP-440 local identifier to prevent publishing because at this
+        # point that is almost certainly not desirable
         tag_data = TagData(tag="0.0.0", offset=None)
     except git.InvalidGitRepositoryError as e:
         log.debug("handling git.InvalidGitRepositoryError, {0}".format(str(e)))
-        raise GitRepoError("Invalid git repository, {0}".format(repo_path)) from e
+        raise GitRepoError(
+            "Invalid git repository, {0}".format(repo_path)
+        ) from e
 
     return tag_data
