@@ -43,14 +43,19 @@ def step_impl(context):
         this_bh_command,
     ):
         mock_project = pathlib.Path(temporary_dir)
+        print(f"project dir, {mock_project}")
+        print(f"cwd before chdir, {os.getcwd()}")
         with chdir_project_dir(mock_project):
-            assert os.getcwd() == str(mock_project)
+            print(f"cwd after chdir, {os.getcwd()}")
 
             this_command = [str(this_bh_command)] + context.given_arguments
             if hasattr(context, "release_id"):
                 this_command += ["--release-id", release_id]
             result = run_command(
-                this_command, capture_output=True, text=True, universal_newlines=True
+                this_command,
+                capture_output=True,
+                text=True,
+                universal_newlines=True,
             )
 
             print(result.stdout)
@@ -70,7 +75,11 @@ def step_impl(context):
 
             if test_install:
                 tmpv_pip = create_venv(mock_project / "tmpv")
-                this_command = [str(tmpv_pip), "install", str(context.dist_dir_list[1])]
+                this_command = [
+                    str(tmpv_pip),
+                    "install",
+                    str(context.dist_dir_list[1]),
+                ]
                 result = run_command(
                     this_command,
                     capture_output=True,
