@@ -31,39 +31,34 @@ class TestRunAnalyses:
         mock_exit = mocker.MagicMock()
         mock_exit.returncode = 1
         mocker.patch(
-            "build_harness.commands.analysis.run_command", return_value=mock_exit
+            "build_harness.commands.analysis.run_command",
+            return_value=mock_exit,
         )
 
-        with pytest.raises(StaticAnalysisError, match=r"^flake8 analysis failed"):
+        with pytest.raises(
+            StaticAnalysisError, match=r"^flake8 analysis failed"
+        ):
             _run_flake8(MOCK_PROJECT_PATH, MOCK_VENV_PATH)
 
     def test_mypy_dirty_exit_raises(self, mocker):
         mock_exit = mocker.MagicMock()
         mock_exit.returncode = 1
         mocker.patch(
-            "build_harness.commands.analysis.run_command", return_value=mock_exit
+            "build_harness.commands.analysis.run_command",
+            return_value=mock_exit,
         )
 
         with pytest.raises(StaticAnalysisError, match=r"^mypy analysis failed"):
             _run_mypy(MOCK_PROJECT_PATH, MOCK_VENV_PATH)
 
-    def test_pydocstyle_dirty_exit_raises(self, mocker):
-        mock_exit = mocker.MagicMock()
-        mock_exit.returncode = 1
-        mocker.patch(
-            "build_harness.commands.analysis.run_command", return_value=mock_exit
-        )
-
-        with pytest.raises(StaticAnalysisError, match=r"^pydocstyle analysis failed"):
-            _run_pydocstyle(MOCK_PROJECT_PATH, MOCK_VENV_PATH)
-
 
 class TestApplyAnalysis:
     def test_all_called(self, mocker):
-        mock_flake8_run = mocker.patch("build_harness.commands.analysis._run_flake8")
-        mock_mypy_run = mocker.patch("build_harness.commands.analysis._run_mypy")
-        mock_pydocstyle_run = mocker.patch(
-            "build_harness.commands.analysis._run_pydocstyle"
+        mock_flake8_run = mocker.patch(
+            "build_harness.commands.analysis._run_flake8"
+        )
+        mock_mypy_run = mocker.patch(
+            "build_harness.commands.analysis._run_mypy"
         )
         mocker.patch(
             "build_harness.commands.analysis.acquire_source_dir",
@@ -78,12 +73,11 @@ class TestApplyAnalysis:
         mock_mypy_run.assert_called_once_with(
             MOCK_PROJECT_PATH / "this/source_dir", MOCK_VENV_PATH
         )
-        mock_pydocstyle_run.assert_called_once_with(
-            MOCK_PROJECT_PATH / "this/source_dir", MOCK_VENV_PATH
-        )
 
     def test_flake8_called(self, mocker):
-        mock_flake8_run = mocker.patch("build_harness.commands.analysis._run_flake8")
+        mock_flake8_run = mocker.patch(
+            "build_harness.commands.analysis._run_flake8"
+        )
         mocker.patch(
             "build_harness.commands.analysis.acquire_source_dir",
             return_value="this/source_dir",
@@ -96,7 +90,9 @@ class TestApplyAnalysis:
         )
 
     def test_mypy_called(self, mocker):
-        mock_mypy_run = mocker.patch("build_harness.commands.analysis._run_mypy")
+        mock_mypy_run = mocker.patch(
+            "build_harness.commands.analysis._run_mypy"
+        )
         mocker.patch(
             "build_harness.commands.analysis.acquire_source_dir",
             return_value="this/source_dir",
@@ -130,14 +126,18 @@ class TestStaticAnalysis:
             "build_harness.commands.analysis._apply_analysis",
             side_effect=RuntimeError(),
         )
-        result = click_runner.invoke(main, ["static-analysis", "--analysis", "flake8"])
+        result = click_runner.invoke(
+            main, ["static-analysis", "--analysis", "flake8"]
+        )
 
         assert result.exit_code == ExitState.UNKNOWN_ERROR.value
 
 
 class TestAll:
     def test_default(self, click_runner, mocker):
-        mock_analysis = mocker.patch("build_harness.commands.analysis._apply_analysis")
+        mock_analysis = mocker.patch(
+            "build_harness.commands.analysis._apply_analysis"
+        )
         mock_formatting = mocker.patch(
             "build_harness.commands.analysis._apply_formatting"
         )
@@ -149,12 +149,16 @@ class TestAll:
         mock_analysis.assert_called_once_with("all", mocker.ANY, mocker.ANY)
 
     def test_explicit(self, click_runner, mocker):
-        mock_analysis = mocker.patch("build_harness.commands.analysis._apply_analysis")
+        mock_analysis = mocker.patch(
+            "build_harness.commands.analysis._apply_analysis"
+        )
         mock_formatting = mocker.patch(
             "build_harness.commands.analysis._apply_formatting"
         )
 
-        result = click_runner.invoke(main, ["static-analysis", "--analysis", "all"])
+        result = click_runner.invoke(
+            main, ["static-analysis", "--analysis", "all"]
+        )
 
         assert result.exit_code == 0
         mock_formatting.assert_called_once()
@@ -169,7 +173,8 @@ class TestAll:
         mock_results = [mocker.create_autospec(subprocess.CompletedProcess)]
         mock_results[0].returncode = 1
         mocker.patch(
-            "build_harness.commands.analysis.run_command", side_effect=mock_results
+            "build_harness.commands.analysis.run_command",
+            side_effect=mock_results,
         )
 
         result = click_runner.invoke(main, ["static-analysis"])
@@ -190,7 +195,8 @@ class TestAll:
         mock_results[0].returncode = 0
         mock_results[1].returncode = 1
         mocker.patch(
-            "build_harness.commands.analysis.run_command", side_effect=mock_results
+            "build_harness.commands.analysis.run_command",
+            side_effect=mock_results,
         )
 
         result = click_runner.invoke(main, ["static-analysis"])
@@ -198,38 +204,19 @@ class TestAll:
         assert result.exit_code == ExitState.MYPY_FAILED.value
         assert "mypy analysis failed" in result.output
 
-    def test_pydocstyle_failure(self, click_runner, mocker):
-        mocker.patch("build_harness.commands.analysis._apply_formatting")
-        mocker.patch(
-            "build_harness.commands.analysis.acquire_source_dir",
-            return_value="something",
-        )
-        mock_results = [
-            mocker.create_autospec(subprocess.CompletedProcess),
-            mocker.create_autospec(subprocess.CompletedProcess),
-            mocker.create_autospec(subprocess.CompletedProcess),
-        ]
-        mock_results[0].returncode = 0
-        mock_results[1].returncode = 0
-        mock_results[2].returncode = 1
-        mocker.patch(
-            "build_harness.commands.analysis.run_command", side_effect=mock_results
-        )
-
-        result = click_runner.invoke(main, ["static-analysis"])
-
-        assert result.exit_code == ExitState.PYDOCSTYLE_FAILED.value
-        assert "pydocstyle analysis failed" in result.output
-
 
 class TestFlake8:
     def test_clean(self, click_runner, mocker):
-        mock_analysis = mocker.patch("build_harness.commands.analysis._apply_analysis")
+        mock_analysis = mocker.patch(
+            "build_harness.commands.analysis._apply_analysis"
+        )
         mock_formatting = mocker.patch(
             "build_harness.commands.analysis._apply_formatting"
         )
 
-        result = click_runner.invoke(main, ["static-analysis", "--analysis", "flake8"])
+        result = click_runner.invoke(
+            main, ["static-analysis", "--analysis", "flake8"]
+        )
 
         assert result.exit_code == 0
         mock_formatting.assert_called_once()
@@ -244,10 +231,13 @@ class TestFlake8:
         mock_results = [mocker.create_autospec(subprocess.CompletedProcess)]
         mock_results[0].returncode = 1
         mocker.patch(
-            "build_harness.commands.analysis.run_command", side_effect=mock_results
+            "build_harness.commands.analysis.run_command",
+            side_effect=mock_results,
         )
 
-        result = click_runner.invoke(main, ["static-analysis", "--analysis", "flake8"])
+        result = click_runner.invoke(
+            main, ["static-analysis", "--analysis", "flake8"]
+        )
 
         assert result.exit_code == ExitState.FLAKE8_FAILED.value
         assert "flake8 analysis failed" in result.output
@@ -255,12 +245,16 @@ class TestFlake8:
 
 class TestMypy:
     def test_clean(self, click_runner, mocker):
-        mock_analysis = mocker.patch("build_harness.commands.analysis._apply_analysis")
+        mock_analysis = mocker.patch(
+            "build_harness.commands.analysis._apply_analysis"
+        )
         mock_formatting = mocker.patch(
             "build_harness.commands.analysis._apply_formatting"
         )
 
-        result = click_runner.invoke(main, ["static-analysis", "--analysis", "mypy"])
+        result = click_runner.invoke(
+            main, ["static-analysis", "--analysis", "mypy"]
+        )
 
         assert result.exit_code == 0
         mock_formatting.assert_called_once()
@@ -275,45 +269,13 @@ class TestMypy:
         mock_results = [mocker.create_autospec(subprocess.CompletedProcess)]
         mock_results[0].returncode = 1
         mocker.patch(
-            "build_harness.commands.analysis.run_command", side_effect=mock_results
+            "build_harness.commands.analysis.run_command",
+            side_effect=mock_results,
         )
 
-        result = click_runner.invoke(main, ["static-analysis", "--analysis", "mypy"])
+        result = click_runner.invoke(
+            main, ["static-analysis", "--analysis", "mypy"]
+        )
 
         assert result.exit_code == ExitState.MYPY_FAILED.value
         assert "mypy analysis failed" in result.output
-
-
-class TestPydocstyle:
-    def test_clean(self, click_runner, mocker):
-        mock_analysis = mocker.patch("build_harness.commands.analysis._apply_analysis")
-        mock_formatting = mocker.patch(
-            "build_harness.commands.analysis._apply_formatting"
-        )
-
-        result = click_runner.invoke(
-            main, ["static-analysis", "--analysis", "pydocstyle"]
-        )
-
-        assert result.exit_code == 0
-        mock_formatting.assert_called_once()
-        mock_analysis.assert_called_once_with("pydocstyle", mocker.ANY, mocker.ANY)
-
-    def test_failure(self, click_runner, mocker):
-        mocker.patch("build_harness.commands.analysis._apply_formatting")
-        mocker.patch(
-            "build_harness.commands.analysis.acquire_source_dir",
-            return_value="something",
-        )
-        mock_results = [mocker.create_autospec(subprocess.CompletedProcess)]
-        mock_results[0].returncode = 1
-        mocker.patch(
-            "build_harness.commands.analysis.run_command", side_effect=mock_results
-        )
-
-        result = click_runner.invoke(
-            main, ["static-analysis", "--analysis", "pydocstyle"]
-        )
-
-        assert result.exit_code == ExitState.PYDOCSTYLE_FAILED.value
-        assert "pydocstyle analysis failed" in result.output
