@@ -47,7 +47,9 @@ class TestValidateGit:
     def test_system_bad(self, mocker):
         mocker.patch("build_harness.tools.git.shutil.which", return_value=None)
 
-        with pytest.raises(GitNotFoundError, match=r"^Git not available on users PATH"):
+        with pytest.raises(
+            GitNotFoundError, match=r"^Git not available on users PATH"
+        ):
             validate_git(None)
 
     def test_user_precedence(self, mocker):
@@ -65,14 +67,18 @@ class TestValidateGit:
 
     def test_user_clean(self, mocker):
         mocker.patch("build_harness.tools.git.shutil.which", return_value=None)
-        mocker.patch("build_harness.tools.git.os.path.exists", return_value=True)
+        mocker.patch(
+            "build_harness.tools.git.os.path.exists", return_value=True
+        )
 
         validate_git("some/other/path")
 
     def test_user_bad(self, mocker):
         mocker.patch("build_harness.tools.git.shutil.which", return_value=None)
 
-        with pytest.raises(GitNotFoundError, match=r"^User specified git invalid"):
+        with pytest.raises(
+            GitNotFoundError, match=r"^User specified git invalid"
+        ):
             validate_git("some/other/path")
 
 
@@ -87,10 +93,12 @@ class SimpleTags(TagBase):
 
 
 @contextlib.contextmanager
-def temp_repo(repo_init: TagBase) -> typing.Generator[git.Repo, None, None]:
+def temp_repo(
+    repo_init: TagBase, initial_branch: str = "main"
+) -> typing.Generator[git.Repo, None, None]:
     with tempfile.TemporaryDirectory() as dir:
         repo_path = pathlib.Path(dir)
-        repo = git.Repo.init(str(repo_path))
+        repo = git.Repo.init(str(repo_path), initial_branch=initial_branch)
         repo_init(repo, repo_path)
 
         yield repo, repo_path
@@ -152,7 +160,10 @@ class TestGetTagData:
         """Dryrun tag on HEAD gets used as-is."""
         expected_tag_data = TagData(tag="3.1+dryrun2")
 
-        with temp_repo(FeatureDryrunTagOnHead("1!2.3a4.dev6")) as (git_repo, repo_path):
+        with temp_repo(FeatureDryrunTagOnHead("1!2.3a4.dev6")) as (
+            git_repo,
+            repo_path,
+        ):
             result = get_tag_data(repo_path)
 
         assert result == expected_tag_data
@@ -161,7 +172,10 @@ class TestGetTagData:
         """Dryrun tags in commit history get ignored."""
         expected_tag_data = TagData(tag="1!2.3a4.dev6", offset="4")
 
-        with temp_repo(FeatureDryrunTags("1!2.3a4.dev6")) as (git_repo, repo_path):
+        with temp_repo(FeatureDryrunTags("1!2.3a4.dev6")) as (
+            git_repo,
+            repo_path,
+        ):
             result = get_tag_data(repo_path)
 
         assert result == expected_tag_data
@@ -173,7 +187,14 @@ class TestGetTagData:
             nb = git_repo.create_head("other_branch")
             git_repo.head.reference = nb
             git_repo.head.reset(index=True, working_tree=True)
-            git_repo.delete_head(git_repo.heads.master)
+            try:
+                git_repo.delete_head(git_repo.heads.main)
+            except AttributeError:
+                # this exception is raised on an attempt to delete a head that
+                # doesn't exist. this test is just trying to define the
+                # appropriate entry state for the test, so just swallow this
+                # error.
+                pass
 
             result = get_tag_data(repo_path, default_branch_name="other_branch")
 
@@ -181,16 +202,23 @@ class TestGetTagData:
 
     def test_semantic_tag_offset(self):
         expected_tag_data = TagData(tag="3.1.4", offset="2")
-        with temp_repo(TagOnDefaultHeadOnFeature("3.1.4")) as (git_repo, repo_path):
+        with temp_repo(TagOnDefaultHeadOnFeature("3.1.4")) as (
+            git_repo,
+            repo_path,
+        ):
             result = get_tag_data(repo_path)
 
         assert result == expected_tag_data
 
     def test_no_tag(self):
+        default_branch = "main"
         expected_tag_data = TagData(tag="0.0.0", offset="1")
 
-        with temp_repo(NoTags()) as (git_repo, repo_path):
-            result = get_tag_data(repo_path)
+        with temp_repo(NoTags(), initial_branch=default_branch) as (
+            git_repo,
+            repo_path,
+        ):
+            result = get_tag_data(repo_path, default_branch_name=default_branch)
 
         assert result == expected_tag_data
 
